==> haskell-ansi-wl-pprint-1.0.2-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-wl-pprint
version:              1.0.2
visibility:           public
id:                   ansi-wl-pprint-1.0.2-425gH57dKcyHojmGTWj2Tl
key:                  ansi-wl-pprint-1.0.2-425gH57dKcyHojmGTWj2Tl
license:              BSD-3-Clause
maintainer:           Edward Kmett <ekmett@gmail.com>
author:               Daan Leijen, Max Bolingbroke
homepage:             http://github.com/ekmett/ansi-wl-pprint
synopsis:
    The Wadler/Leijen Pretty Printer for colored ANSI terminal output

description:
    This is a pretty printing library based on Wadler'\''s paper ["A Prettier Printer"](https://homepages.inf.ed.ac.uk/wadler/papers/prettier/prettier.pdf).
    It has been enhanced with support for ANSI terminal colored output using the [ansi-terminal](https://hackage.haskell.org/package/ansi-terminal) package.

category:             User Interfaces, Text
abi:                  81f14117870dfdc6f99ea5d2e3615904
exposed:              True
exposed-modules:      Text.PrettyPrint.ANSI.Leijen
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ansi-wl-pprint-1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ansi-wl-pprint-1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ansi-wl-pprint-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-wl-pprint
hs-libraries:         HSansi-wl-pprint-1.0.2-425gH57dKcyHojmGTWj2Tl
depends:
    base-4.17.2.1
    prettyprinter-compat-ansi-wl-pprint-1.0.2-Hoj3GgjMu1rFc6BTGEYASZ

haddock-interfaces:
    /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-wl-pprint-1.0.2-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-wl-pprint
version:              1.0.2
visibility:           public
id:                   ansi-wl-pprint-1.0.2-IAL52HT6KEh7gkp1x0f5Yt
key:                  ansi-wl-pprint-1.0.2-IAL52HT6KEh7gkp1x0f5Yt
license:              BSD-3-Clause
maintainer:           Edward Kmett <ekmett@gmail.com>
author:               Daan Leijen, Max Bolingbroke
homepage:             http://github.com/ekmett/ansi-wl-pprint
synopsis:
    The Wadler/Leijen Pretty Printer for colored ANSI terminal output

description:
    This is a pretty printing library based on Wadler'\''s paper ["A Prettier Printer"](https://homepages.inf.ed.ac.uk/wadler/papers/prettier/prettier.pdf).
    It has been enhanced with support for ANSI terminal colored output using the [ansi-terminal](https://hackage.haskell.org/package/ansi-terminal) package.

category:             User Interfaces, Text
abi:                  56a6b06f08ec62b0ea21c1dfa2309570
exposed:              True
exposed-modules:      Text.PrettyPrint.ANSI.Leijen
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ansi-wl-pprint-1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ansi-wl-pprint-1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ansi-wl-pprint-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-wl-pprint
hs-libraries:         HSansi-wl-pprint-1.0.2-IAL52HT6KEh7gkp1x0f5Yt
depends:
    base-4.17.2.1
    prettyprinter-compat-ansi-wl-pprint-1.0.2-3ogo7GGnKyR5rqH0ABuDCf

haddock-interfaces:
    /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
